@@ -96,6 +96,7 @@ class State402(object):
 
 
 class OperationMode(object):
+    NO_MODE = 0
     PROFILED_POSITION = 1
     VELOCITY = 2
     PROFILED_VELOCITY = 3
@@ -109,6 +110,7 @@ class OperationMode(object):
     OPEN_LOOP_VECTOR_MODE = -2
 
     CODE2NAME = {
+        NO_MODE                     : 'NO MODE',
         PROFILED_POSITION           : 'PROFILED POSITION',
         VELOCITY                    : 'VELOCITY',
         PROFILED_VELOCITY           : 'PROFILED VELOCITY',
@@ -118,6 +120,7 @@ class OperationMode(object):
     }
 
     NAME2CODE = {
+        'NO MODE'                       : NO_MODE,
         'PROFILED POSITION'             : PROFILED_POSITION,
         'VELOCITY'                      : VELOCITY,
         'PROFILED VELOCITY'             : PROFILED_VELOCITY,
@@ -127,6 +130,7 @@ class OperationMode(object):
     }
 
     SUPPORTED = {
+        'NO MODE'                     : 0x0,
         'PROFILED POSITION'           : 0x1,
         'VELOCITY'                    : 0x2,
         'PROFILED VELOCITY'           : 0x4,
@@ -217,10 +221,11 @@ class BaseNode402(RemoteNode):
         # If RPDOs have overlapping indecies, rpdo_pointers will point to 
         # the first RPDO that has that index configured.
         for rpdo in self.rpdo.values():
-            for obj in rpdo:
-                logger.debug('Configured RPDO: {0}'.format(obj.index))
-                if obj.index not in self.rpdo_pointers:
-                    self.rpdo_pointers[obj.index] = obj 
+            if rpdo.enabled:
+                for obj in rpdo:
+                    logger.debug('Configured RPDO: {0}'.format(obj.index))
+                    if obj.index not in self.rpdo_pointers:
+                        self.rpdo_pointers[obj.index] = obj
 
     def _check_controlword_configured(self):
         if 0x6040 not in self.rpdo_pointers: # Controlword
@@ -308,6 +313,7 @@ class BaseNode402(RemoteNode):
         :rtype: bool
 
         The modes can be:
+        - 'NO MODE'
         - 'PROFILED POSITION'
         - 'VELOCITY'
         - 'PROFILED VELOCITY'
@@ -439,7 +445,7 @@ class BaseNode402(RemoteNode):
         timeout = time.time() + 0.8 # 800 ms
         while self.state != target_state:
             next_state = self._next_state(target_state)
-            if _change_state(next_state):
+            if self._change_state(next_state):
                 continue       
             if time.time() > timeout:
                 raise RuntimeError('Timeout when trying to change state')
